@@ -11,7 +11,6 @@ Help::Help(QWidget *parent) :
     ui(new Ui::Help)
 {
     ui->setupUi(this);
-
 }
 
 Help::~Help()
@@ -32,4 +31,7 @@ void Help::on_pushButtonWiki_clicked()
      QDesktopServices::openUrl(QUrl("http://wiki.maemo.org/Bander"));
 }
 
-
+void Help::on_pushButtonGf_clicked()
+{
+     QDesktopServices::openUrl(QUrl("http://www.gentleface.com"));
+}
