@@ -3,10 +3,10 @@
 
 #include "about.h"
 #include "help.h"
-#include "resistors.h"
-#include "calculations.h"
-#include "caps.h"
-#include "netcable.h"
+#include "bands.h"
+#include "ohms.h"
+#include "values.h"
+#include "selectwindows/pinouts.h"
 
 #include <QtCore/QCoreApplication>
 #include <QDesktopServices>
@@ -18,10 +18,10 @@ MainWindow::MainWindow(QWidget *parent):
     ui(new Ui::MainWindow),
       about(0),
       help(0),
-      caps(0),
-      resistors(0),
-      calculations(0),
-      netcable(0)
+      bands(0),
+      ohms(0),
+      values(0),
+      pinouts(0)
 {
     ui->setupUi(this);
 
@@ -29,12 +29,25 @@ MainWindow::MainWindow(QWidget *parent):
     this->setWindowTitle("Bander");
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
+    //Set Button Text
+    ui->pushButtonBands->setText(tr("Band Converter"));
+    ui->pushButtonOhms->setText(tr("Ohm's Law"));
+    ui->pushButtonValues->setText(tr("Value Converter"));
+    ui->pushButtonPinouts->setText(tr("Pinouts"));
+
+    // Set Button Icons
+    ui->pushButtonBands->setIcon(QPixmap("/opt/bander/icons/align_just_icon&32.png"));
+    ui->pushButtonOhms->setIcon(QPixmap("/opt/bander/icons/sq_up_icon&32.png"));
+    ui->pushButtonValues->setIcon(QPixmap("/opt/bander/icons/calc_icon&32.png"));
+    ui->pushButtonPinouts->setIcon(QPixmap("/opt/bander/icons/push_pin_icon&32.png"));
+
+
     about = new About(this);
     help = new Help(this);
-    caps = new Caps(this);
-    resistors = new Resistors(this);
-    calculations = new Calculations(this);
-    netcable = new Netcable(this);
+    bands = new Bands(this);
+    ohms = new Ohms(this);
+    values = new Values(this);
+    pinouts = new Pinouts(this);
 
     // For Connecting Keyboard Buttons
     connectSignals();
@@ -44,10 +57,10 @@ MainWindow::~MainWindow()
 {
     if (about) delete (about);
     if (help) delete (help);
-    if (caps) delete (caps);
-    if (resistors) delete (resistors);
-    if (calculations) delete (calculations);
-    if (netcable) delete (netcable);
+    if (bands) delete (bands);
+    if (ohms) delete (ohms);
+    if (values) delete (values);
+    if (pinouts) delete (pinouts);
     delete ui;
 }
 
@@ -110,10 +123,10 @@ void MainWindow::connectSignals()
 {
 
 // Keyboard Key Signals
-  connect(new QShortcut(QKeySequence(Qt::Key_Q), this), SIGNAL(activated()), this, SLOT(on_pushButtonColors_clicked()));
-  connect(new QShortcut(QKeySequence(Qt::Key_W), this), SIGNAL(activated()), this, SLOT(on_pushButtonCalculations_clicked()));
-  connect(new QShortcut(QKeySequence(Qt::Key_E), this), SIGNAL(activated()), this, SLOT(on_pushButtonCaps_clicked()));
-  connect(new QShortcut(QKeySequence(Qt::Key_R), this), SIGNAL(activated()), this, SLOT(on_pushButtonNetcable_clicked()));
+  connect(new QShortcut(QKeySequence(Qt::Key_Q), this), SIGNAL(activated()), this, SLOT(on_pushButtonBands_clicked()));
+  connect(new QShortcut(QKeySequence(Qt::Key_W), this), SIGNAL(activated()), this, SLOT(on_pushButtonOhms_clicked()));
+  connect(new QShortcut(QKeySequence(Qt::Key_E), this), SIGNAL(activated()), this, SLOT(on_pushButtonValues_clicked()));
+  connect(new QShortcut(QKeySequence(Qt::Key_R), this), SIGNAL(activated()), this, SLOT(on_pushButtonPinouts_clicked()));
 }
 
 // End of Keyboard Signals
@@ -130,22 +143,22 @@ void MainWindow::on_actionHelp_triggered()
     help->show();
 }
 
-void MainWindow::on_pushButtonCalculations_clicked()
+void MainWindow::on_pushButtonBands_clicked()
 {
-    calculations->show();
+    bands->show();
 }
 
-void MainWindow::on_pushButtonCaps_clicked()
+void MainWindow::on_pushButtonOhms_clicked()
 {
-    caps->show();
+    ohms->show();
 }
 
-void MainWindow::on_pushButtonColors_clicked()
+void MainWindow::on_pushButtonValues_clicked()
 {
-    resistors->show();
+    values->show();
 }
 
-void MainWindow::on_pushButtonNetcable_clicked()
+void MainWindow::on_pushButtonPinouts_clicked()
 {
-    netcable->show();
+    pinouts->show();
 }
