@@ -5,10 +5,10 @@
 
 class About;
 class Help;
-class Caps;
-class Resistors;
-class Calculations;
-class Netcable;
+class Bands;
+class Ohms;
+class Values;
+class Pinouts;
 
 namespace Ui {
     class MainWindow;
@@ -43,22 +43,22 @@ private slots:
 
     void on_actionHelp_triggered();
 
-    void on_pushButtonCalculations_clicked();
+    void on_pushButtonBands_clicked();
 
-    void on_pushButtonCaps_clicked();
+    void on_pushButtonOhms_clicked();
 
-    void on_pushButtonColors_clicked();
+    void on_pushButtonValues_clicked();
 
-    void on_pushButtonNetcable_clicked();
+    void on_pushButtonPinouts_clicked();
 
 private:
     Ui::MainWindow *ui;
     About *about;
     Help *help;
-    Caps *caps;
-    Resistors *resistors;
-    Calculations *calculations;
-    Netcable *netcable;
+    Bands *bands;
+    Ohms *ohms;
+    Values *values;
+    Pinouts *pinouts;
 };
 
 #endif // MAINWINDOW_H
