@@ -1,5 +1,5 @@
 #ifndef UTILITIES_H
-#define UTILITIESS_H
+#define UTILITIES_H
 
 #include <QString>
 
